@@ -2,10 +2,11 @@
 
 variant=$1
 
+INDIR=`dirname $0`
 OUTFILE=base.l${variant}v${variant}_s.part
 
 > $OUTFILE
 
 awk '{ 
   printf "  %s		%s	=	+%s(%s):'${variant}'\n", $1, $2, $3, $4; 
-}' < variantRename.lst >> $OUTFILE
+}' < $INDIR/variantRename.lst >> $OUTFILE
